/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2013-2023 Chaosdorf e.V.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package de.chaosdorf.meteroid.ui.servers

import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material3.ListItem
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.unit.dp
import androidx.navigation.NavController
import coil.compose.AsyncImage
import de.chaosdorf.meteroid.ui.navigation.Routes
import okhttp3.HttpUrl.Companion.toHttpUrl

@Composable
fun ServerListScreen(
  navController: NavController,
  viewModel: ServerListViewModel,
  contentPadding: PaddingValues = PaddingValues(),
) {
  val servers by viewModel.servers.collectAsState()

  LazyColumn(contentPadding = contentPadding) {
    items(servers) { server ->
      ListItem(
        headlineContent = { Text(server.name ?: server.url) },
        supportingContent = { if (server.name != null) Text(server.url.toHttpUrl().host) },
        leadingContent = {
          AsyncImage(
            server.logoUrl,
            contentDescription = null,
            contentScale = ContentScale.Crop,
            modifier = Modifier.size(48.dp)
          )
        },
        modifier = Modifier.clickable {
          navController.navigate(Routes.Users.list(server.serverId))
          viewModel.selectServer(server.serverId)
        }
      )
    }
    item {
      ListItem(
        headlineContent = { Text("Add Server") },
        modifier = Modifier.clickable {
          navController.navigate(Routes.Servers.Add)
        }
      )
    }
  }
}
